<?xml version="1.0"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                extension-element-prefixes="msxsl"
                xmlns:frmwrk="Corel Framework Data"
                exclude-result-prefixes="frmwrk">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<frmwrk:uiconfig>
		<frmwrk:applicationInfo userConfiguration="true" />
	</frmwrk:uiconfig>

	<!-- Helper "insert" mode for applying XSLT templates -->
	<xsl:template match="node()|@*" mode="insert">
		<xsl:param name='nodes'/>
		<xsl:variable name='container' select='.'/>
		<xsl:copy>
			<xsl:apply-templates select='@*'/>
			<xsl:apply-templates select='msxsl:node-set($nodes)/beginning/*'/>
			<xsl:for-each select="./*">
				<xsl:variable name='itemGuid' select='@guid'/>
				<xsl:variable name='itemGuidRef' select='@guidRef'/>
				<xsl:apply-templates select='msxsl:node-set($nodes)/before[@guid=$itemGuid or @guidRef=$itemGuidRef]/*'/>
				<xsl:apply-templates select="."/>
				<xsl:apply-templates select='msxsl:node-set($nodes)/after[@guid=$itemGuid or @guidRef=$itemGuidRef]/*'/>
			</xsl:for-each>
			<xsl:apply-templates select='msxsl:node-set($nodes)/end/*'/>
		</xsl:copy>
	</xsl:template>

	<!-- By default, copy all the nodes -->
	<xsl:template match="node()|@*">
		<xsl:copy>
			<xsl:apply-templates select="node()|@*"/>
		</xsl:copy>
	</xsl:template>
	<!-- UI item definitions -->
	<xsl:template match="uiConfig/items">
		<xsl:apply-templates select="." mode="insert">
			<xsl:with-param name="nodes">
				<!-- Append the following items to the end of uiConfig/items node -->
				<end>
					<itemData guid="d509273d-5975-4481-a6a2-e4351cd7bbd6"
										type="checkButton"
										noBmpOnMenu="true"
										check="*Docker('2ab4fce9-f07d-482d-b95e-b1b5b18e75d2')"
										newForVersion="18"/>

					<!-- Density Label -->
					<itemData guid="87c7a00e-5f8a-4751-bef7-b0c17b5f2a1f"
										type="statusText"
										appearance="controlHeight"
										captionRef="566ae1dd-253c-4081-bfbc-f500521bf713"/>
					<!-- Density slider -->
					<itemData guid="566ae1dd-253c-4081-bfbc-f500521bf713"
										type="popupSlider"
										numDecimalPlaces="0"
										value="*Bind(DataSource=VectorEffectsDS;Path=DpiValue;BindType=TwoWay)"
										rangeMin="1"
										rangeMax="300" />

					<!-- Angle Label -->
					<itemData guid="9dfee06a-04a7-4ea2-80df-0914a084aea2"
										type="statusText"
										appearance="controlHeight"
										captionRef="d8e73d51-997a-4992-af00-25a1b3e1bbb1"/>
					<!-- Angle spinner -->
					<itemData guid="d8e73d51-997a-4992-af00-25a1b3e1bbb1"
										type="spinner"
										rightLabelIcon="guid://b74aa9d4-0f3c-4668-a6f6-4d0519bb8412"
										value="*Bind(DataSource=VectorEffectsDS;Path=Angle;BindType=TwoWay)"
										increment="5"
										numDecimalPlaces="*Bind(DataSource=WPrefsApp;Path=DrawingPrecision)"
										rangeMax="360"
										rangeMin="-360" 
										showSpinner="false" />

					<!-- Limit Colors Check -->
					<itemData guid="edb8c302-01a9-4a25-a3af-67cca3dd4e90"
										type="checkButton"
										tooltip="*ResS('7800ac87-9810-29a5-4dd8-416f49142833')"
										appearance="dialog"
										check="*Bind(DataSource=VectorEffectsDS;Path=LimitColors;BindType=TwoWay)"/>
					<!-- Num Colors slider -->
					<itemData guid="2abb3ed9-94a2-4a24-bd84-6286264796e3"
										type="popupSlider"
										value="*Bind(DataSource=VectorEffectsDS;Path=NumColors;BindType=TwoWay)"
										enable="*Bind(DataSource=VectorEffectsDS;Path=LimitColors)"
										numDecimalPlaces="0"
										rangeMin="2"
										rangeMax="256"
										increment="1" />

					<!-- Method Label -->
					<itemData guid="8fdb063c-4cfd-4838-a420-90202104b18a"
										type="statusText"
										appearance="controlHeight"
										captionRef="00ddde32-872a-4858-8b31-e18448876aa1"/>
					<!-- Method Combo -->
					<itemData guid="00ddde32-872a-4858-8b31-e18448876aa1"
										type="comboBoxEx"
										currentItem="*Bind(DataSource=VectorEffectsDS;Path=ScaleMode;BindType=TwoWay)"
										items="*Bind(DataSource=VectorEffectsDS;Path=ScaleModeList)"/>

					<!-- Merge Adjacent Label -->
					<itemData guid="3bea36ae-ae9c-459e-b04c-439c313fdc94"
										type="statusText"
										appearance="controlHeight"
										captionRef="17226b35-3245-4654-b137-5521a124ab5f"/>
					<!-- Merge adjacent slider -->
					<itemData guid="17226b35-3245-4654-b137-5521a124ab5f"
										type="popupSlider"
										value="*Bind(DataSource=VectorEffectsDS;Path=CombineFactor;BindType=TwoWay)"
										numDecimalPlaces="0"
										rangeMin="1"
										rangeMax="100"
										increment="1" />

					<!-- Scale Label -->
					<itemData guid="65073fdd-2898-41cb-a3f9-9b0ef8594da8"
										type="statusText"
										appearance="controlHeight"
										captionRef="d7af77c1-fcbd-4338-a05e-60571ca6a620"/>
					<!-- Scale slider -->
					<itemData guid="d7af77c1-fcbd-4338-a05e-60571ca6a620"
										type="popupSlider"
										value="*Bind(DataSource=VectorEffectsDS;Path=Scale;BindType=TwoWay)"
										numDecimalPlaces="2"
										rangeMin="0.05"
										rangeMax="2.0"
										increment="0.05" />

					<!-- Shape Label -->
					<itemData guid="cf91b428-ae31-476c-a78d-ff5f57a54e2a"
										type="statusText"
										appearance="controlHeight"
										captionRef="c8493c5b-d3b8-409b-87de-2a36be641270"/>
					<!-- Shape Combo -->
					<itemData guid="c8493c5b-d3b8-409b-87de-2a36be641270"
										type="comboBoxEx"
										currentItem="*Bind(DataSource=VectorEffectsDS;Path=Shape;BindType=TwoWay)"
										items="*Bind(DataSource=VectorEffectsDS;Path=ShapeList)"/>

					<!-- Shape Preview -->
					<itemData guid="ccedc242-d3b2-4c92-b6e4-2c65b3a1466f"
										type="statusText"
										border="solid"
										item="*Bind(DataSource=VectorEffectsDS;Path=ShapePreview)"/>
					<!-- Layout Item (to preserve row height when button is invisible) -->
					<itemData guid="3d17247c-87c1-ac9b-4099-c36c28ec9421"
										type="statusText"
										appearance="controlHeight" />
					<!-- Shape Select -->
					<itemData guid="7c7794be-570c-4636-a7b5-db0d1b5bd6de"
										type="button"
										appearance="dialog"
										onInvoke="*Bind(DataSource=VectorEffectsDS;Path=OnPickShape)"
										enable="*Bind(DataSource=VectorEffectsDS;Path=PickShapeEnabled)"
										visible="*Bind(DataSource=VectorEffectsDS;Path=PickShapeEnabled)"/>

					<!-- Weld adjacent check -->
					<itemData guid="cd949cef-ba2c-4cf5-b1ad-9ab1a62e3c93"
										type="checkButton"
										appearance="dialog"
										check="*Bind(DataSource=VectorEffectsDS;Path=WeldPixels;BindType=TwoWay)"
										enable="*Bind(DataSource=VectorEffectsDS;Path=WeldPixelsEnabled)" />

					<!-- Apply -->
					<itemData guid="02d7471b-9164-44fe-9cdb-b15cff4af11c"
										type="button"
										appearance="dialog"
										onInvoke="*Bind(DataSource=VectorEffectsDS;Path=OnApply)"
										enable="*Bind(DataSource=VectorEffectsDS;Path=ApplyEnabled)"/>

					<!-- Source Label -->
					<itemData guid="c6c53ad2-07c7-c9bc-471d-7412afbe055c"
										type="statusText"
										appearance="controlHeight"/>
					<!-- Keep Original -->
					<itemData guid="5b957b22-b2fc-298c-45e2-bb769034ea1a"
										type="checkButton"
										appearance="dialog"
										check="*Bind(DataSource=VectorEffectsDS;Path=KeepSource;BindType=TwoWay)"/>
					<!-- Colors Label -->
					<itemData guid="5bff6c3b-cc70-3b82-4ee3-3df341be3e6b"
										type="statusText"
										appearance="controlHeight"
										/>
					<!-- Colors > Number Label -->
					<itemData guid="b1a8168e-79e7-9d83-4dbd-731443928159"
										type="statusText"
										appearance="controlHeight"
										captionRef="2abb3ed9-94a2-4a24-bd84-6286264796e3"/>
					<!-- Tracing options -->
					<itemData guid="b26013c7-38e2-f390-43aa-b104ff1b97c2"
										type="statusText"
										appearance="controlHeight"/>
					<!-- Overlap Label -->
					<itemData guid="3356f678-5d0e-0298-4025-440d8ddf0518"
										type="statusText"
										appearance="controlHeight"/>
					<!-- Left Angle Icon -->
					<itemData guid="f04a55f2-c761-0ba2-4932-c3d9bd23a17a"
										type="statusText"
										icon="guid://99164887-b36f-5093-4147-a53e1e440c0d"
										appearance="controlHeight" />
					<!-- Help/Info Icon -->
					<itemData guid="d82157ab-2ff7-5f98-468a-a4562f23ba58"
										type="button"
										icon="guid://f5f05c26-5b53-3bbf-42ae-7630b4a92882"
										onInvoke="*Bind(DataSource=VectorEffectsDS;Path=OnlineHelp)"
										captionRef="1d2744d3-cd3f-7485-488c-696bc4d72fcb"/>
					<!-- Online help -->
					<itemData guid="1d2744d3-cd3f-7485-488c-696bc4d72fcb"
										type="button"
										appearance="textLinkLeftAligned"
										onInvoke="*Bind(DataSource=VectorEffectsDS;Path=OnlineHelp)"
										visible="true"/>
					<!-- In Progress -->
					<itemData guid="d4425f76-7aa9-9f94-4afd-7aa42c2ae934"
										type="statusText"
										appearance="controlHeight"
										visible="*Bind(DataSource=VectorEffectsDS;Path=InProgress)"/>
					<!-- Esc or Cancel -->
					<itemData guid="0578c35c-5888-faa6-4b85-34b2652619d5"
										type="statusText"
										multiLine="true"
										appearance="controlHeight"
										visible="*Bind(DataSource=VectorEffectsDS;Path=InProgress)"/>
				</end>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>

	<!-- Docker -->
	<xsl:template match="uiConfig/dockers">
		<xsl:apply-templates select="." mode="insert">
			<xsl:with-param name="nodes">
				<end>
					<dockerData guid="2ab4fce9-f07d-482d-b95e-b1b5b18e75d2" captionRef="d509273d-5975-4481-a6a2-e4351cd7bbd6" icon="guid://d509273d-5975-4481-a6a2-e4351cd7bbd6" defaultPushButton="02d7471b-9164-44fe-9cdb-b15cff4af11c">
						<container>
							<gridContainer dock="top" colDefs="14,*,2*" layout="fit">
								<item Grid.Row="+" Grid.ColumnSpan="2" guidRef="87c7a00e-5f8a-4751-bef7-b0c17b5f2a1f" automationName="DpiLabel" itemFace="textOnly"/>
								<item Grid.Column="2" guidRef="566ae1dd-253c-4081-bfbc-f500521bf713" dock="fill" automationName="Dpi"/>

								<item Grid.Row="+" Grid.ColumnSpan="2" guidRef="65073fdd-2898-41cb-a3f9-9b0ef8594da8" automationName="ScaleLabel"/>
								<item Grid.Column="2" guidRef="d7af77c1-fcbd-4338-a05e-60571ca6a620" dock="fill" automationName="Scale"/>

								<container Grid.Row="+" Grid.ColumnSpan="2">
									<item guidRef="9dfee06a-04a7-4ea2-80df-0914a084aea2" dock="fill" automationName="AngleLabel"/>
									<item guidRef="f04a55f2-c761-0ba2-4932-c3d9bd23a17a" dock="right" automationName="LeftAngleIcon" itemFace="imageOnly"/>
								</container>
								<item Grid.Column="2" guidRef="d8e73d51-997a-4992-af00-25a1b3e1bbb1" dock="fill" automationName="Angle"/>

								<item Grid.Row="+" Grid.ColumnSpan="2" guidRef="c6c53ad2-07c7-c9bc-471d-7412afbe055c" automationName="SourceLabel"/>
								<item Grid.Column="2" guidRef="5b957b22-b2fc-298c-45e2-bb769034ea1a" dock="fill" automationName="KeepOriginal"/>

								<!-- Separator -->
								<item Grid.Row="+" Grid.ColumnSpan="3" guidRef="266435b4-6e53-460f-9fa7-f45be187d400" dock="fill"/>

								<item Grid.Row="+" Grid.ColumnSpan="2" guidRef="5bff6c3b-cc70-3b82-4ee3-3df341be3e6b" automationName="ColorsLabel"/>
								<item Grid.Column="2" guidRef="edb8c302-01a9-4a25-a3af-67cca3dd4e90" automationName="LimitColors"/>

								<item Grid.Row="+" Grid.Column="1" guidRef="b1a8168e-79e7-9d83-4dbd-731443928159" automationName="ColorsNumberLabel"/>
								<item Grid.Column="2" guidRef="2abb3ed9-94a2-4a24-bd84-6286264796e3" dock="fill" automationName="NumColors"/>

								<!-- Separator -->
								<item Grid.Row="+" Grid.ColumnSpan="3" guidRef="266435b4-6e53-460f-9fa7-f45be187d400" dock="fill"/>

								<item Grid.Row="+" Grid.ColumnSpan="2" guidRef="b26013c7-38e2-f390-43aa-b104ff1b97c2" automationName="TracingOptionsLabel"/>

								<item Grid.Row="+" Grid.Column="1" guidRef="8fdb063c-4cfd-4838-a420-90202104b18a" automationName="ScaleModeLabel"/>
								<item Grid.Column="2" guidRef="00ddde32-872a-4858-8b31-e18448876aa1" dock="fill" automationName="ScaleMode"/>

								<item Grid.Row="+" Grid.Column="1" guidRef="3bea36ae-ae9c-459e-b04c-439c313fdc94" dock="fill" automationName="MergeAdjacentLabel"/>
								<item Grid.Column="2" guidRef="17226b35-3245-4654-b137-5521a124ab5f" dock="fill" automationName="MergeAdjacent"/>

								<item Grid.Row="+" Grid.Column="1" guidRef="3356f678-5d0e-0298-4025-440d8ddf0518" automationName="OverlapLabel"/>
								<item Grid.Column="2" guidRef="cd949cef-ba2c-4cf5-b1ad-9ab1a62e3c93" automationName="WeldAdjacent"/>

								<!-- Separator -->
								<item Grid.Row="+" Grid.ColumnSpan="3" guidRef="266435b4-6e53-460f-9fa7-f45be187d400" dock="fill"/>

								<container Grid.Row="+" Grid.ColumnSpan="2">
									<item guidRef="cf91b428-ae31-476c-a78d-ff5f57a54e2a" dock="top" automationName="ShapeLabel"/>
								</container>

								<gridContainer dock="fill" interItemSpacingOff="true" Grid.Column="2">
									<item Grid.Row="+" guidRef="c8493c5b-d3b8-409b-87de-2a36be641270" dock="fill" automationName="Shape"/>
									<item Grid.Row="+" guidRef="ccedc242-d3b2-4c92-b6e4-2c65b3a1466f" automationName="ShapePreview"/>
									<item Grid.Row="+" guidRef="7c7794be-570c-4636-a7b5-db0d1b5bd6de" automationName="PickShape" dock="fill"/>
								</gridContainer>

								<!-- Separator -->
								<item Grid.Row="+" Grid.ColumnSpan="3" guidRef="266435b4-6e53-460f-9fa7-f45be187d400" dock="fill"/>

								<container Grid.Row="+" Grid.ColumnSpan="3">
									<item guidRef="02d7471b-9164-44fe-9cdb-b15cff4af11c" dock="fill" automationName="ApplyOrCancel"/>
								</container>

								<container Grid.Row="+" Grid.ColumnSpan="3">
									<gridContainer dock="fill" colDefs="26,75+">
										<container Grid.Row="+" >
											<item dock="fill" guidRef="d82157ab-2ff7-5f98-468a-a4562f23ba58" automationName="HelpInfoIcon"/>
										</container>
										<container Grid.Column="1">
											<container dock="left">
												<item guidRef="1d2744d3-cd3f-7485-488c-696bc4d72fcb" dock="fill" itemFace="textOnly" automationName="HelpText" />
												<item guidRef="d4425f76-7aa9-9f94-4afd-7aa42c2ae934" dock="top" automationName="InProgressText" />
												<item guidRef="0578c35c-5888-faa6-4b85-34b2652619d5" dock="top" automationName="EscCancelText"/>
											</container>
										</container>
									</gridContainer>
								</container>
							</gridContainer>
						</container>
					</dockerData>
				</end>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>

	<!-- Helper template that will insert items into a container where requested -->
	<xsl:template match="node()|@*" mode="insert-item">
		<xsl:param name="after"></xsl:param>
		<xsl:param name="before"></xsl:param>
		<xsl:param name="content"></xsl:param>
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:for-each select="node()">
				<xsl:if test="name()='item' and @guidRef=$before">
					<xsl:copy-of select="$content"/>
				</xsl:if>
				<xsl:copy>
					<xsl:apply-templates select="node()|@*"/>
				</xsl:copy>
				<xsl:if test="name()='item' and @guidRef=$after">
					<xsl:copy-of select="$content"/>
				</xsl:if>
			</xsl:for-each>
			<xsl:if test="not(./item[@guidRef=$after]) and not(./item[@guidRef=$before])">
				<xsl:copy-of select="$content"/>
			</xsl:if>
		</xsl:copy>
	</xsl:template>

	<!-- Add new item to Effects menu DRAW -->
	<xsl:template match="//commandBarData[@guid='21cd018a-87c1-476c-9a98-a8e36b9c479e']/menu">
		<xsl:apply-templates mode="insert-item" select=".">
			<xsl:with-param name="after">1c86e69f-30a5-4a01-85cb-e4a76cca5fd5</xsl:with-param>
			<xsl:with-param name="content">
				<xsl:if test="not(./item[@guidRef='d509273d-5975-4481-a6a2-e4351cd7bbd6'])">
					<item guidRef="d509273d-5975-4481-a6a2-e4351cd7bbd6"/>
				</xsl:if>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>

	<!-- Add new item to Docker/Effects menu -->
	<xsl:template match="//commandBarData[@guid='d5a436af-9c4d-3c9b-4519-02ec82b80aab']/menu">
		<xsl:apply-templates mode="insert-item" select=".">
			<xsl:with-param name="after">6268eac5-0cf7-4d43-a20a-aacc50b04562</xsl:with-param>
			<xsl:with-param name="content">
				<xsl:if test="not(./item[@guidRef='d509273d-5975-4481-a6a2-e4351cd7bbd6'])">
					<item guidRef="d509273d-5975-4481-a6a2-e4351cd7bbd6"/>
				</xsl:if>
			</xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>
</xsl:stylesheet>